==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/ToolCommandEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolCommandDescriptionMetadata } from "./ToolCommandDescriptionMetadata";
import { ToolCommandEventArgsDescription } from "./ToolCommandEventArgsDescription";
/**
 * @hidden
 */
export let ToolCommandEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class ToolCommandEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (ToolCommandEventArgsDescriptionMetadata.a == null) {
                ToolCommandEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ToolCommandEventArgsDescriptionMetadata.c(ToolCommandEventArgsDescriptionMetadata.a);
            }
            if (a.j(ToolCommandEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(ToolCommandEventArgsDescriptionMetadata.a);
            ToolCommandDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("Command", "ExportedType:ToolCommand");
        }
        static d(a) {
            ToolCommandEventArgsDescriptionMetadata.b(a);
            a.aa("ToolCommandEventArgs", () => new ToolCommandEventArgsDescription());
            a.z("ToolCommandEventArgs", ToolCommandEventArgsDescriptionMetadata.a);
        }
    }
    ToolCommandEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(ToolCommandEventArgsDescriptionMetadata, 'ToolCommandEventArgsDescriptionMetadata');
    ToolCommandEventArgsDescriptionMetadata.a = null;
    return ToolCommandEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/ToolCommandEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolCommandDescriptionMetadata } from "./ToolCommandDescriptionMetadata";
import { ToolCommandEventArgsDescription } from "./ToolCommandEventArgsDescription";
/**
 * @hidden
 */
export let ToolCommandEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class ToolCommandEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (ToolCommandEventArgsDescriptionMetadata.a == null) {
                ToolCommandEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ToolCommandEventArgsDescriptionMetadata.c(ToolCommandEventArgsDescriptionMetadata.a);
            }
            if (a.k(ToolCommandEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(ToolCommandEventArgsDescriptionMetadata.a);
            ToolCommandDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("Command", "ExportedType:ToolCommand");
        }
        static d(a) {
            ToolCommandEventArgsDescriptionMetadata.b(a);
            a.ac("ToolCommandEventArgs", () => new ToolCommandEventArgsDescription());
            a.ab("ToolCommandEventArgs", ToolCommandEventArgsDescriptionMetadata.a);
        }
    }
    ToolCommandEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(ToolCommandEventArgsDescriptionMetadata, 'ToolCommandEventArgsDescriptionMetadata');
    ToolCommandEventArgsDescriptionMetadata.a = null;
    return ToolCommandEventArgsDescriptionMetadata;
})();
